@@ -1,3 +1,5 @@
+utils::globalVariables(c("day_start", "ae", "treat", "tot", "day_end", "flag"))
+
 #' count_event  Count the event number for every AE at specified timepoint
 #'
 #' @description  Count the event number for every AE at specified timepoint
@@ -9,7 +11,6 @@
 
 
 count_event <- function(total = tot, day = 1){
-  day_start <- ae <- treat <- tot <- day_end <- flag <- NULL
 
   tmp <- total %>%
     tidyr::drop_na() %>%
