@@ -10,9 +10,13 @@
 
 preproc_patients <- function(patients, height) {
   # set patient positions in layout of circles:
+  # use function set_vector_layout from set_vector_layout.R file
   vec_lay    <- set_vector_layout(patients, height)
+  # use function set_width() from set_width.R file
   width      <- set_width(patients, height)
-  patients$X <- rep(2*cumsum(width)-1, each = height)[which(vec_lay != 0)]
-  patients$Y <- rep(seq(-1,-2*height+1, by = -2), length(width))[which(vec_lay != 0)]
+  if (dim(patients)[1] == length(rep(2 * cumsum(width) - 1, each = height)[which(vec_lay != 0)])) {
+  patients$X <- rep(2 * cumsum(width) - 1, each = height)[which(vec_lay != 0)]
+  patients$Y <- rep(seq(-1, -2 * height + 1, by = -2), length(width))[which(vec_lay != 0)]
   return(patients)
+  }
 }
