@@ -18,7 +18,7 @@ ui <- shiny::shinyUI(
         )
       )
     ),
-    shiny::tags$style(type = "text/css", "body { overflow-y: scroll; }",
+    shiny::tags$style(type = "text/css",# "body { overflow-y: scroll; }",
       paste0(".recalculating {opacity: 1.0;}
         .irs-bar {width: 100%; height: 25px; background: #377eb8; border-top: 1px solid #377eb8; border-bottom: 1px solid #377eb8;}
         .irs-bar-edge {background: #377eb8; border: 1px solid #377eb8; height: 25px; border-radius: 5px; width: 20px;}
@@ -36,12 +36,12 @@ ui <- shiny::shinyUI(
         .panel.panel-default{background-color:#383838; color:#ffffff;border-color:#6b6b6b}
         .panel-heading{color:#ffffff;padding:0;}
         .panel-title{background:#383838; color:#ffffff;margin-top:10px;margin-bottom:10px;padding-left:5px}
-        body {background-color: #424242; color: #6b6b6b}
+        body {background-color: #424242; color: #6b6b6b;}
         .panel-group.sbs-panel-group {position: absolute; width: 100%;}
         .panel.panel-default {background-color: #383838; color: #ffffff; border-color: #6b6b6b}
         .panel-heading {color: #ffffff; padding: 0;}
         .panel-title {background: #383838;color: #ffffff; margin-top: 10px; margin-bottom: 10px; padding-left: 5px}
-        .myRow1 {background-color: #383838; height: 150px;}
+        .myRow1 {background-color: #383838; height: 150px; }
         .myRow3 {background-color: #424242;}
         #plot_hoverinfo {background-color: #424242; color: #ffffff; border-color: #383838; font-size: 14px;}
         #overall_info{background-color: #424242; color: #ffffff; border-color: #383838; font-size: 14px;}
@@ -49,7 +49,7 @@ ui <- shiny::shinyUI(
       )
     ),
     # Main panel
-    shiny::mainPanel(
+    shiny::mainPanel(style = "padding-right: 0px; padding-left: 0px;", #class = "myRow1",
       shiny::fluidRow(class = "myRow1",
         shiny::column(2,
           shiny::br(),
@@ -213,7 +213,13 @@ ui <- shiny::shinyUI(
                     shiny::uiOutput("ae_audio"),
                     shiny::uiOutput("ae_sound1"),
                     shiny::uiOutput("ae_sound2")
-                  )
+                  ),
+                  shinyWidgets::materialSwitch(
+                    inputId = "show_imputations",
+                    label = "Mark adverse events with imputed start or/and end date",
+                    value = FALSE
+                  ),
+                  shiny::uiOutput("text_imputations")
                 ),
                 shinyBS::bsCollapsePanel(
                   shiny::HTML('<p style="color:white; font-size:100%;"> Subgroup setting </p>'),
@@ -335,7 +341,7 @@ ui <- shiny::shinyUI(
           shiny::column(2,
             adeproLogo(height = 120, width = 120, align = "right"),
             shiny::tags$div(style="text-align:center",
-              shiny::HTML(paste0("<span style='color: white'> v.", utils::packageVersion("adepro"), " </span>"))
+              shiny::HTML(paste0("<span style='color: white'> v.",packageVersion("adepro"),"</span>"))
             )
           )
         ),
@@ -452,12 +458,18 @@ ui <- shiny::shinyUI(
           						</p>
           						<p>
           							The '<b>barplot view</b>' displays the aggregated numbers
-          							for the selected adverse events
+          							for the selected adverse events.
           						</p>
           						<p>
           							The top bar of the app includes several other options which
           							are further explained under 'Functionality'.
           						</p>
+          						<p>
+            						By clicking a single circle in the plot, the subject will be displayed as highlighted.
+                        It is also possible to highlight all subjects with a specific adverse events by selecting the event
+                        in the legend on the left side.
+                        To remove the selection simply re-click adverse event or subject selected.
+                      </p>
                       ")
                     ),
                     circle = TRUE,
@@ -804,7 +816,7 @@ ui <- shiny::shinyUI(
                     shiny::wellPanel(
                       id = "table_ae_Panel",
                       style = "color:black; overflow-y:scroll; max-height: 600px",
-                      DT::DTOutput('table_ae')
+                      shiny::dataTableOutput('table_ae')
                     )
                   ),
                   multiple = TRUE,
@@ -813,7 +825,7 @@ ui <- shiny::shinyUI(
                   shinyBS::bsCollapsePanel(
                     shiny::HTML('<p style="color:white; font-size:100%;"> adsl data (click to open/close table): </p>'),
                     shiny::wellPanel(id = "table_ae_Panel",style = "color:black; overflow-y:scroll; max-height: 600px",
-                      DT::DTOutput('table_pat')
+                      shiny::dataTableOutput('table_pat')
                     )
                   )
                 )
@@ -825,7 +837,7 @@ ui <- shiny::shinyUI(
           conditionalPanel(condition = "input.sortTreatments.length > 0",
           shiny::uiOutput('ae_summary_box')
           ),
-          shiny::plotOutput(outputId = "legend", width = "100%", height = "45px"),
+          #shiny::plotOutput(outputId = "legend", width = "100%"),#, height = "45px"),
           shiny::conditionalPanel(condition = "input.view == 'pie'",
             shiny::uiOutput('patientpanel'),
 
@@ -833,11 +845,23 @@ ui <- shiny::shinyUI(
             shiny::conditionalPanel(condition = "input.sortTreatments.length == 0",
               shiny::HTML('<p style="text-align:center;color:white;"> Please select at least one treatment in the "Modify data"-Panel! </p>')
             ),
-              shiny::plotOutput(outputId = "legend2", width = "100%",height ="25px"),
-              shiny::plotOutput(
-                outputId = "slicePlots",
-                hover = hoverOpts(id ="plot_hover")
+            shiny::fluidRow(
+              splitLayout(
+                cellArgs = list(style='white-space: normal; resize: horizontal;'),
+                cellWidths = c("9%", "82%","9%"),
+                shiny::uiOutput("circle_legend"),
+                shiny::plotOutput(
+                  outputId = "slicePlots",
+                  hover = hoverOpts(id ="plot_hover"),
+                  click = clickOpts(id = "plot_click"),
+                  height = "100%"
+                ),
+                shiny::uiOutput("circle_legend2")
               )
+            ),
+            shiny::fluidRow(
+
+            )
           ),
           shiny::conditionalPanel(condition = "input.view == 'chart'",
             shiny::conditionalPanel(condition = "input.sortTreatments.length > 0",
